@@ -14,8 +14,11 @@ from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
 __title__ = 'vcspull'
-__version__ = '0.0.7'
+__package_name__ = 'vcspull'
+__description__ = 'Mass update git, hg and svn repos simultaneously from YAML / JSON file.'
+__version__ = '0.0.8'
 __author__ = 'Tony Narlock'
+__email__ = 'tony@git-pull.com'
 __license__ = 'BSD'
 __copyright__ = 'Copyright 2013 Tony Narlock'
 
